OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Tags",
    "Tagged files" : "Getagde bestanden",
    "Select tags to filter by" : "Selecteer tags om op te filteren",
    "Please select tags to filter by" : "Selecteer tags om op te filteren",
    "No files found for the selected tags" : "Geen bestanden gevonden voor de geselecteerde tags",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systeem tags</strong> voor een bestand zijn gewijzigd",
    "You assigned system tag %3$s" : "Je wees systeem tag %3$s toe",
    "%1$s assigned system tag %3$s" : "%1$s wees systeem tag %3$s toe",
    "You unassigned system tag %3$s" : "Je maakte toewijzing systeem tag %3$s ongedaan",
    "%1$s unassigned system tag %3$s" : "%1$s verwijderde systeem tag %3$s",
    "You created system tag %2$s" : "Je creëerde systeem tag %2$s",
    "%1$s created system tag %2$s" : "%1$s creëerde systeem tag %2$s",
    "You deleted system tag %2$s" : "Je verwijderde systeem tag %2$s",
    "%1$s deleted system tag %2$s" : "%1$s verwijderde systeem tag %2$s van het systeem",
    "You updated system tag %3$s to %2$s" : "U werkte systeemtag %3$s bij naar  %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hernoemde systeem tag %3$s naar %2$s",
    "You assigned system tag %3$s to %2$s" : "Je wees systeem tag %3$s aan %2$s toe",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s wees systeem tag %3$s aan %2$s toe",
    "You unassigned system tag %3$s from %2$s" : "Je maakte toewijzing systeem tag %3$s van %2$s ongedaan",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s verwijderde systeem tag %3$s van %2$s",
    "%s (restricted)" : "%s (beperkt)",
    "%s (invisible)" : "%s (onzichtbaar)",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast"
},
"nplurals=2; plural=(n != 1);");
